@@ -2,38 +2,45 @@ from __future__ import absolute_import
 from __future__ import print_function
 from __future__ import unicode_literals
 
+import uuid
+
 from django.core.urlresolvers import reverse
+from django.utils.timezone import now
+from le_utils.constants import content_kinds
 from rest_framework import status
 from rest_framework.test import APITestCase
 
 from .. import models
 from kolibri.core import error_constants
+from kolibri.core.auth.models import AdHocGroup
+from kolibri.core.auth.models import Classroom
 from kolibri.core.auth.models import Facility
 from kolibri.core.auth.models import FacilityUser
 from kolibri.core.auth.models import LearnerGroup
 from kolibri.core.auth.test.helpers import provision_device
-from kolibri.core.logger.models import ExamLog
+from kolibri.core.logger.models import ContentSummaryLog
+from kolibri.core.logger.models import MasteryLog
 
 
 DUMMY_PASSWORD = "password"
 
 
 class ExamAPITestCase(APITestCase):
-    def setUp(self):
+    @classmethod
+    def setUpTestData(cls):
         provision_device()
-        self.facility = Facility.objects.create(name="MyFac")
-        self.admin = FacilityUser.objects.create(
-            username="admin", facility=self.facility
-        )
-        self.admin.set_password(DUMMY_PASSWORD)
-        self.admin.save()
-        self.facility.add_admin(self.admin)
-        self.exam = models.Exam.objects.create(
+        cls.facility = Facility.objects.create(name="MyFac")
+        cls.admin = FacilityUser.objects.create(username="admin", facility=cls.facility)
+        cls.admin.set_password(DUMMY_PASSWORD)
+        cls.admin.save()
+        cls.facility.add_admin(cls.admin)
+        cls.classroom = Classroom.objects.create(name="Classroom", parent=cls.facility)
+        cls.exam = models.Exam.objects.create(
             title="title",
             question_count=1,
             active=True,
-            collection=self.facility,
-            creator=self.admin,
+            collection=cls.classroom,
+            creator=cls.admin,
         )
 
     def make_basic_exam(self):
@@ -41,7 +48,7 @@ class ExamAPITestCase(APITestCase):
             "title": "Exam",
             "question_count": 1,
             "active": True,
-            "collection": self.facility.id,
+            "collection": self.classroom.id,
             "learners_see_fixed_order": False,
             "question_sources": [],
             "assignments": [],
@@ -100,6 +107,37 @@ class ExamAPITestCase(APITestCase):
             models.Exam.objects.get(id=exam_id),
         )
 
+    def test_logged_in_admin_exam_create_with_learner_assignments(self):
+        self.login_as_admin()
+        exam = self.make_basic_exam()
+        user = FacilityUser.objects.create(username="u", facility=self.facility)
+
+        self.classroom.add_member(user)
+        exam["learner_ids"] = [user.id]
+        response = self.post_new_exam(exam)
+        exam_id = response.data["id"]
+        self.assertEqual(response.status_code, 201)
+        adhoc_group = AdHocGroup.objects.get(parent=self.classroom)
+        self.assertEqual(len(adhoc_group.get_members()), 1)
+        self.assertEqual(adhoc_group.get_members()[0], user)
+        self.assertEqual(
+            models.ExamAssignment.objects.get(collection=adhoc_group).exam,
+            models.Exam.objects.get(id=exam_id),
+        )
+
+    def test_logged_in_admin_exam_create_with_learner_assignments_for_wrong_collection(
+        self,
+    ):
+        self.login_as_admin()
+        exam = self.make_basic_exam()
+        user = FacilityUser.objects.create(username="u", facility=self.facility)
+
+        exam["learner_ids"] = [user.id]
+        response = self.post_new_exam(exam)
+        self.assertEqual(response.status_code, 400)
+        with self.assertRaises(AdHocGroup.DoesNotExist):
+            AdHocGroup.objects.get(parent=self.classroom)
+
     def test_logged_in_admin_exam_update_no_assignments(self):
         self.login_as_admin()
         exam = self.make_basic_exam()
@@ -117,7 +155,7 @@ class ExamAPITestCase(APITestCase):
         exam["assignments"] = [self.facility.id]
         post_response = self.post_new_exam(exam)
         exam_id = post_response.data["id"]
-        group = LearnerGroup.objects.create(name="test", parent=self.facility)
+        group = LearnerGroup.objects.create(name="test", parent=self.classroom)
         exam["assignments"] = [group.id]
         put_response = self.put_updated_exam(exam_id, exam)
         self.assertEqual(put_response.status_code, 200)
@@ -131,7 +169,7 @@ class ExamAPITestCase(APITestCase):
         exam["assignments"] = [self.facility.id]
         post_response = self.post_new_exam(exam)
         exam_id = post_response.data["id"]
-        group = LearnerGroup.objects.create(name="test", parent=self.facility)
+        group = LearnerGroup.objects.create(name="test", parent=self.classroom)
         exam["assignments"].append(group.id)
         put_response = self.put_updated_exam(exam_id, exam)
         self.assertEqual(put_response.status_code, 200)
@@ -155,44 +193,56 @@ class ExamAPITestCase(APITestCase):
             models.Exam.objects.get(id=self.exam.id).title, "updated title"
         )
 
-    def test_close_exam_logs_when_exam_is_closed(self):
+    def test_complete_mastery_logs_when_exam_is_closed(self):
         self.login_as_admin()
-        group = LearnerGroup.objects.create(name="test", parent=self.facility)
+        group = LearnerGroup.objects.create(name="test", parent=self.classroom)
 
-        import datetime
-
-        EXAM_LOGS = 0
+        MASTERY_LOGS = 0
         for i in range(10):
             user = FacilityUser.objects.create(
                 username="u{}".format(i), facility=self.facility
             )
 
+            self.classroom.add_member(user)
+
             # Add the user to the learner group
             group.add_learner(user)
 
             # Half of the students will _start_ the exam, half won't. So we will have
-            # 5 ExamLogs for this exam.
+            # 5 MasteryLogs for this exam.
             if i <= 5:
-                ExamLog.objects.create(
-                    closed=False,
-                    exam_id=self.exam.id,
-                    user_id=user.id,
-                    completion_timestamp=datetime.datetime.now(),
-                    dataset_id=self.exam.dataset_id,
+                summarylog = ContentSummaryLog.objects.create(
+                    user=user,
+                    start_timestamp=now(),
+                    end_timestamp=now(),
+                    completion_timestamp=now(),
+                    content_id=self.exam.id,
+                    kind=content_kinds.QUIZ,
                 )
-                EXAM_LOGS = EXAM_LOGS + 1
+                MasteryLog.objects.create(
+                    mastery_criterion={"type": "quiz", "coach_assigned": True},
+                    summarylog=summarylog,
+                    start_timestamp=summarylog.start_timestamp,
+                    user=user,
+                    mastery_level=-1,
+                )
+                MASTERY_LOGS = MASTERY_LOGS + 1
 
-        open_exam_logs = ExamLog.objects.filter(exam_id=self.exam.id, closed=False)
+        open_mastery_logs = MasteryLog.objects.filter(
+            summarylog__content_id=self.exam.id, complete=False
+        )
         # Make sure that the open exams in the DB match that which we counted above.
-        self.assertEquals(EXAM_LOGS, len(open_exam_logs))
+        self.assertEquals(MASTERY_LOGS, len(open_mastery_logs))
 
         # Finally - make the request.
         self.put_updated_exam(self.exam.id, {"archive": True})
-        exam_logs = ExamLog.objects.filter(exam_id=self.exam.id)
-        closed_exam_logs = ExamLog.objects.filter(exam_id=self.exam.id, closed=True)
-        # No new ExamLogs made - but all that were made previously are closed.
-        self.assertEquals(len(closed_exam_logs), len(exam_logs))
-        self.assertEquals(EXAM_LOGS, len(closed_exam_logs))
+        mastery_logs = MasteryLog.objects.filter(summarylog__content_id=self.exam.id)
+        closed_mastery_logs = MasteryLog.objects.filter(
+            summarylog__content_id=self.exam.id, complete=True
+        )
+        # No new MasteryLogs made - but all that were made previously are complete.
+        self.assertEquals(len(closed_mastery_logs), len(mastery_logs))
+        self.assertEquals(MASTERY_LOGS, len(closed_mastery_logs))
 
     def test_logged_in_user_exam_no_update(self):
         self.login_as_learner()
@@ -218,8 +268,8 @@ class ExamAPITestCase(APITestCase):
         exam["title"] = title
         exam["question_sources"].append(
             {
-                "exercise_id": "e1e1e1e1e1e1e1e1e1e1e1e1e1e1e1e1",
-                "question_id": "q1",
+                "exercise_id": uuid.uuid4().hex,
+                "question_id": uuid.uuid4().hex,
                 "title": "Title",
                 # missing 'counter_in_exercise'
             }
@@ -234,6 +284,20 @@ class ExamAPITestCase(APITestCase):
         exam["question_sources"].append(
             {
                 "exercise_id": "e1",
+                "question_id": uuid.uuid4().hex,
+                "title": "Title",
+                "counter_in_exercise": 1,
+            }
+        )
+        response = self.post_new_exam(exam)
+        self.assertEqual(response.status_code, 400)
+
+    def test_exam_with_invalid_question_id(self):
+        self.login_as_admin()
+        exam = self.make_basic_exam()
+        exam["question_sources"].append(
+            {
+                "exercise_id": uuid.uuid4().hex,
                 "question_id": "q1",
                 "title": "Title",
                 "counter_in_exercise": 1,
@@ -242,13 +306,26 @@ class ExamAPITestCase(APITestCase):
         response = self.post_new_exam(exam)
         self.assertEqual(response.status_code, 400)
 
-    def test_exam_with_valid_question_sources_succeeds(self):
+    def test_exam_with_no_question_id_succeeds(self):
         self.login_as_admin()
         exam = self.make_basic_exam()
         exam["question_sources"].append(
             {
-                "exercise_id": "e1e1e1e1e1e1e1e1e1e1e1e1e1e1e1e1",
-                "question_id": "q1",
+                "exercise_id": uuid.uuid4().hex,
+                "title": "Title",
+                "counter_in_exercise": 1,
+            }
+        )
+        response = self.post_new_exam(exam)
+        self.assertEqual(response.status_code, 201)
+
+    def test_exam_with_valid_question_sources_succeeds(self):
+        self.login_as_admin()
+        exam = self.make_basic_exam()
+        exam["question_sources"].append(
+            {
+                "exercise_id": uuid.uuid4().hex,
+                "question_id": uuid.uuid4().hex,
                 "title": "Title",
                 "counter_in_exercise": 1,
             }
