@@ -2,15 +2,18 @@ import importlib
 import logging
 import time
 import uuid
+from threading import Thread
+
+from django.utils.functional import SimpleLazyObject
+from six import string_types
 
 from kolibri.core.tasks import compat
-from kolibri.core.utils.cache import ProcessLock
 
 
 # An object on which to store data about the current job
 # So far the only use is to track the job, but other metadata
 # could be added.
-current_state_tracker = compat.local()
+current_state_tracker = SimpleLazyObject(compat.local)
 
 
 def get_current_job():
@@ -18,13 +21,16 @@ def get_current_job():
 
 
 def stringify_func(func):
-    if not callable(func):
-        raise TypeError(
-            "function {} passed to stringify_func isn't a function!".format(func)
+    if callable(func):
+        funcstring = "{module}.{funcname}".format(
+            module=func.__module__, funcname=func.__name__
         )
+    elif isinstance(func, string_types):
+        funcstring = func
+    else:
+        raise TypeError("Can't handle a function of type {}".format(type(func)))
 
-    fqn = "{module}.{funcname}".format(module=func.__module__, funcname=func.__name__)
-    return fqn
+    return funcstring
 
 
 def import_stringified_func(funcstring):
@@ -35,7 +41,7 @@ def import_stringified_func(funcstring):
     :param funcstring: String to try to import
     :return: callable
     """
-    if not isinstance(funcstring, str):
+    if not isinstance(funcstring, string_types):
         raise TypeError("Argument must be a string")
 
     modulestring, funcname = funcstring.rsplit(".", 1)
@@ -46,10 +52,10 @@ def import_stringified_func(funcstring):
     return func
 
 
-class InfiniteLoopThread(compat.Thread):
+class InfiniteLoopThread(Thread):
     """A class that runs a given function an infinite number of times, until told to shut down."""
 
-    DEFAULT_TIMEOUT_SECONDS = 0.2
+    DEFAULT_TIMEOUT_SECONDS = 0.001
 
     def __init__(self, func, thread_name, wait_between_runs=1, *args, **kwargs):
         """
@@ -118,6 +124,3 @@ class InfiniteLoopThread(compat.Thread):
 
     def shutdown(self):
         self.stop()
-
-
-db_task_write_lock = ProcessLock("db_task_write_lock")
