@@ -29,9 +29,6 @@ from kolibri.core.device.utils import allow_guest_access
 from kolibri.core.device.utils import device_provisioned
 from kolibri.core.hooks import LogoutRedirectHook
 from kolibri.core.hooks import RoleBasedRedirectHook
-from kolibri.core.theme_hook import BRAND_COLORS
-from kolibri.core.theme_hook import COLOR_V400
-from kolibri.core.theme_hook import PRIMARY
 from kolibri.core.theme_hook import ThemeHook
 
 
@@ -178,9 +175,9 @@ class UnsupportedBrowserView(TemplateView):
         context = super(UnsupportedBrowserView, self).get_context_data(**kwargs)
         context["brand_primary_v400"] = (
             ThemeHook.get_theme()
-            .get(BRAND_COLORS, {})
-            .get(PRIMARY, {})
-            .get(COLOR_V400, "purple")
+            .get("brandColors", {})
+            .get("primary", {})
+            .get("v_400", "#212121")
         )
         return context
 
