@@ -15,6 +15,7 @@ from django.utils.functional import SimpleLazyObject
 from django.utils.six import string_types
 from six.moves.urllib.parse import urlparse
 from six.moves.urllib.parse import urlunparse
+from validate import is_boolean
 from validate import Validator
 from validate import VdtTypeError
 from validate import VdtValueError
@@ -47,6 +48,10 @@ FD_PER_THREAD = sum(
     )
 )
 
+# Reserve some file descriptors for file operations happening in asynchronous tasks
+# when the server is running with threaded task runners.
+MIN_RESERVED_FD = 64
+
 
 def calculate_thread_pool():
     """
@@ -79,8 +84,9 @@ def calculate_thread_pool():
         pool_size = MAX_POOL
 
     # ensure (number of threads) x (open file descriptors) < (fd limit)
-    max_threads = get_fd_limit() // FD_PER_THREAD
-    return min(pool_size, max_threads)
+    max_threads = (get_fd_limit() - MIN_RESERVED_FD) // FD_PER_THREAD
+    # Ensure that the number of threads never goes below 1
+    return max(1, min(pool_size, max_threads))
 
 
 ALL_LANGUAGES = "kolibri-all"
@@ -222,6 +228,24 @@ def url_prefix(value):
     return value.lstrip("/").rstrip("/") + "/"
 
 
+def multiprocess_bool(value):
+    """
+    Validate the boolean value of a multiprocessing option.
+    Do this by checking it's a boolean, and also that multiprocessing
+    can be imported properly on this platform.
+    """
+    value = is_boolean(value)
+    try:
+        if not value:
+            raise ImportError()
+        # Import in order to check if multiprocessing is supported on this platform
+        from multiprocessing import synchronize  # noqa
+
+        return True
+    except ImportError:
+        return False
+
+
 base_option_spec = {
     "Cache": {
         "CACHE_BACKEND": {
@@ -529,13 +553,27 @@ base_option_spec = {
     },
     "Tasks": {
         "USE_WORKER_MULTIPROCESSING": {
-            "type": "boolean",
+            "type": "multiprocess_bool",
             "default": False,
             "description": """
                 Whether to use Python multiprocessing for worker pools. If False, then it will use threading. This may be useful,
                 if running on a dedicated device with multiple cores, and a lot of asynchronous tasks get run.
             """,
-        }
+        },
+        "REGULAR_PRIORITY_WORKERS": {
+            "type": "integer",
+            "default": 4,
+            "description": """
+                The number of workers to spin up for regular priority asynchronous tasks.
+            """,
+        },
+        "HIGH_PRIORITY_WORKERS": {
+            "type": "integer",
+            "default": 2,
+            "description": """
+                The number of workers to spin up for high priority asynchronous tasks.
+            """,
+        },
     },
 }
 
@@ -550,6 +588,7 @@ def _get_validator():
             "port": port,
             "url_prefix": url_prefix,
             "bytes": validate_bytes,
+            "multiprocess_bool": multiprocess_bool,
         }
     )
 
