@@ -18,10 +18,7 @@ from __future__ import unicode_literals
 
 import logging
 import os
-import signal
 import sys
-import tempfile
-import time
 
 import six
 from django.db import connections
@@ -48,41 +45,6 @@ def _posix_pid_exists(pid):
         return True
 
 
-def _kill_pid(pid, softkill_signal_number):
-    """Kill a PID by sending a signal, starting with a softer one and then escalating as needed"""
-    logger.info("Initiating shutdown of Kolibri")
-    try:
-        logger.debug("Attempting to soft kill process with pid %d..." % pid)
-        os.kill(pid, softkill_signal_number)
-        logger.debug("Soft kill signal sent without error.")
-    # process does not exist
-    except OSError:
-        logger.debug(
-            "Soft kill signal could not be sent (OSError); process may not exist?"
-        )
-        return
-    if pid_exists(pid):
-        logger.info("Waiting for Kolibri to finish shutting down")
-    # give some time for the process to clean itself up gracefully before we force anything
-    i = 0
-    while pid_exists(pid) and i < 60:
-        time.sleep(0.5)
-        i += 1
-    # if process didn't exit cleanly, make one last effort to kill it
-    if pid_exists(pid):
-        logger.debug(
-            "Process wth pid %s still exists after soft kill signal; attempting a SIGKILL."
-            % pid
-        )
-        os.kill(pid, signal.SIGKILL)
-        logger.debug("SIGKILL signal sent without error.")
-
-
-def _posix_kill_pid(pid):
-    """Kill a PID by sending a posix-specific soft-kill signal"""
-    _kill_pid(pid, signal.SIGTERM)
-
-
 def _windows_pid_exists(pid):
     import ctypes
 
@@ -93,13 +55,7 @@ def _windows_pid_exists(pid):
     if process != 0:
         kernel32.CloseHandle(process)
         return True
-    else:
-        return False
-
-
-def _windows_kill_pid(pid):
-    """Kill a PID by sending a windows-specific soft-kill signal"""
-    _kill_pid(pid, signal.CTRL_C_EVENT)
+    return False
 
 
 buffering = int(six.PY3)  # No unbuffered text I/O on Python 3 (#20815).
@@ -198,8 +154,9 @@ def get_free_space(path=KOLIBRI_HOME):
             from jnius import autoclass
 
             StatFs = autoclass("android.os.StatFs")
+            AndroidString = autoclass("java.lang.String")
 
-            st = StatFs(KOLIBRI_HOME)
+            st = StatFs(AndroidString(path))
 
             try:
                 # for api version 18+
@@ -214,7 +171,7 @@ def get_free_space(path=KOLIBRI_HOME):
         st = os.statvfs(os.path.realpath(path))
         result = st.f_bavail * st.f_frsize
 
-    return result
+    return max(result - OPTIONS["Deployment"]["MINIMUM_DISK_SPACE"], 0)
 
 
 _become_daemon_function = None
@@ -227,38 +184,32 @@ def become_daemon(**kwargs):
     _become_daemon_function(**kwargs)
 
 
-# Utility functions for pinging or killing PIDs
+def _posix_get_fd_limit():
+    """
+    Determines the File Descriptor (FD) limit
+    :return: int
+    """
+    import resource
+
+    fd_soft_limit, _ = resource.getrlimit(resource.RLIMIT_NOFILE)
+    return fd_soft_limit
+
+
+def _windows_get_fd_limit():
+    """
+    Determines the File Descriptor (FD) limit
+    :return: int
+    """
+    # TODO: "determine" it
+    return 512
+
+
+# Utility functions
 if os.name == "posix":
     pid_exists = _posix_pid_exists
-    kill_pid = _posix_kill_pid
+    get_fd_limit = _posix_get_fd_limit
     _become_daemon_function = _posix_become_daemon
 else:
     pid_exists = _windows_pid_exists
-    kill_pid = _windows_kill_pid
+    get_fd_limit = _windows_get_fd_limit
     _become_daemon_function = _windows_become_daemon
-
-
-def _symlink_capability_check():
-    """
-    Function to try to establish a symlink
-    return True if it succeeds, return False otherwise.
-    """
-    # If STATIC_USE_SYMLINKS has been set to False, return False directly
-    if not OPTIONS["Deployment"]["STATIC_USE_SYMLINKS"]:
-        return False
-
-    fd, temp_target = tempfile.mkstemp()
-    temp_pathname = temp_target + ".lnk"
-    can_do = True
-    try:
-        os.symlink(temp_target, temp_pathname)
-        os.remove(temp_pathname)
-    except OSError:
-        can_do = False
-    # Explicitly close the file so that we can remove it on windows
-    os.close(fd)
-    os.remove(temp_target)
-    return can_do
-
-
-CAN_USE_SYMLINKS = _symlink_capability_check()
